@@ -25,16 +25,16 @@
   UIOBuffer.cc
 
 **************************************************************************/
-#include "ts/ink_defs.h"
+#include "tscore/ink_defs.h"
 #include "P_EventSystem.h"
 
 //
 // General Buffer Allocator
 //
-inkcoreapi Allocator ioBufAllocator[DEFAULT_BUFFER_SIZES];
-inkcoreapi ClassAllocator<MIOBuffer> ioAllocator("ioAllocator", DEFAULT_BUFFER_NUMBER);
-inkcoreapi ClassAllocator<IOBufferData> ioDataAllocator("ioDataAllocator", DEFAULT_BUFFER_NUMBER);
-inkcoreapi ClassAllocator<IOBufferBlock> ioBlockAllocator("ioBlockAllocator", DEFAULT_BUFFER_NUMBER);
+Allocator ioBufAllocator[DEFAULT_BUFFER_SIZES];
+ClassAllocator<MIOBuffer> ioAllocator("ioAllocator", DEFAULT_BUFFER_NUMBER);
+ClassAllocator<IOBufferData> ioDataAllocator("ioDataAllocator", DEFAULT_BUFFER_NUMBER);
+ClassAllocator<IOBufferBlock> ioBlockAllocator("ioBlockAllocator", DEFAULT_BUFFER_NUMBER);
 int64_t default_large_iobuffer_size = DEFAULT_LARGE_BUFFER_SIZE;
 int64_t default_small_iobuffer_size = DEFAULT_SMALL_BUFFER_SIZE;
 int64_t max_iobuffer_size           = DEFAULT_BUFFER_SIZES - 1;
@@ -43,56 +43,34 @@ int64_t max_iobuffer_size           = DEFAULT_BUFFER_SIZES - 1;
 // Initialization
 //
 void
-init_buffer_allocators()
+init_buffer_allocators(int iobuffer_advice)
 {
-  char *name;
-  int advice = 0;
-
-#ifdef MADV_DONTDUMP // This should only exist on Linux 3.4 and higher.
-  advice = MADV_DONTDUMP;
-#endif
-
   for (int i = 0; i < DEFAULT_BUFFER_SIZES; i++) {
-    int64_t s = DEFAULT_BUFFER_BASE_SIZE * (((int64_t)1) << i);
+    int64_t s = DEFAULT_BUFFER_BASE_SIZE * ((static_cast<int64_t>(1)) << i);
     int64_t a = DEFAULT_BUFFER_ALIGNMENT;
     int n     = i <= default_large_iobuffer_size ? DEFAULT_BUFFER_NUMBER : DEFAULT_HUGE_BUFFER_NUMBER;
-    if (s < a)
+    if (s < a) {
       a = s;
-
-    name = new char[64];
-    snprintf(name, 64, "ioBufAllocator[%d]", i);
-    ioBufAllocator[i].re_init(name, s, n, a, advice);
-  }
-}
-
-int64_t
-MIOBuffer::remove_append(IOBufferReader *r)
-{
-  int64_t l = 0;
-  while (r->block) {
-    Ptr<IOBufferBlock> b = r->block;
-    r->block             = r->block->next;
-    b->_start += r->start_offset;
-    if (b->start() >= b->end()) {
-      r->start_offset = -r->start_offset;
-      continue;
     }
-    r->start_offset = 0;
-    l += b->read_avail();
-    append_block(b.get());
+
+    auto name = new char[64];
+    snprintf(name, 64, "ioBufAllocator[%d]", i);
+    ioBufAllocator[i].re_init(name, s, n, a, iobuffer_advice);
   }
-  r->mbuf->_writer = NULL;
-  return l;
 }
 
+//
+// MIOBuffer
+//
 int64_t
 MIOBuffer::write(const void *abuf, int64_t alen)
 {
-  const char *buf = (const char *)abuf;
+  const char *buf = static_cast<const char *>(abuf);
   int64_t len     = alen;
   while (len) {
-    if (!_writer)
+    if (!_writer) {
       add_block();
+    }
     int64_t f = _writer->write_avail();
     f         = f < len ? f : len;
     if (f > 0) {
@@ -102,46 +80,32 @@ MIOBuffer::write(const void *abuf, int64_t alen)
       len -= f;
     }
     if (len) {
-      if (!_writer->next)
+      if (!_writer->next) {
         add_block();
-      else
+      } else {
         _writer = _writer->next;
+      }
     }
   }
   return alen;
 }
 
-#ifdef WRITE_AND_TRANSFER
-/*
- * Same functionality as write but for the one small difference.
- * The space available in the last block is taken from the original
- * and this space becomes available to the copy.
- *
- */
 int64_t
-MIOBuffer::write_and_transfer_left_over_space(IOBufferReader *r, int64_t alen, int64_t offset)
+MIOBuffer::write(IOBufferReader *r, int64_t len, int64_t offset)
 {
-  int64_t rval = write(r, alen, offset);
-  // reset the end markers of the original so that it cannot
-  // make use of the space in the current block
-  if (r->mbuf->_writer)
-    r->mbuf->_writer->_buf_end = r->mbuf->_writer->_end;
-  // reset the end marker of the clone so that it can make
-  // use of the space in the current block
-  if (_writer) {
-    _writer->_buf_end = _writer->data->data() + _writer->block_size();
-  }
-  return rval;
+  return this->write(r->block.get(), len, offset + r->start_offset);
 }
 
-#endif
+int64_t
+MIOBuffer::write(IOBufferChain const *chain, int64_t len, int64_t offset)
+{
+  return this->write(chain->head(), std::min(len, chain->length()), offset);
+}
 
 int64_t
-MIOBuffer::write(IOBufferReader *r, int64_t alen, int64_t offset)
+MIOBuffer::write(IOBufferBlock const *b, int64_t alen, int64_t offset)
 {
-  int64_t len      = alen;
-  IOBufferBlock *b = r->block.get();
-  offset += r->start_offset;
+  int64_t len = alen;
 
   while (b && len > 0) {
     int64_t max_bytes = b->read_avail();
@@ -152,7 +116,7 @@ MIOBuffer::write(IOBufferReader *r, int64_t alen, int64_t offset)
       continue;
     }
     int64_t bytes;
-    if (len < 0 || len >= max_bytes) {
+    if (len >= max_bytes) {
       bytes = max_bytes;
     } else {
       bytes = len;
@@ -169,43 +133,47 @@ MIOBuffer::write(IOBufferReader *r, int64_t alen, int64_t offset)
   return alen - len;
 }
 
-int64_t
-MIOBuffer::puts(char *s, int64_t len)
+bool
+MIOBuffer::is_max_read_avail_more_than(int64_t size)
 {
-  char *pc = end();
-  char *pb = s;
-  while (pc < buf_end()) {
-    if (len-- <= 0)
-      return -1;
-    if (!*pb || *pb == '\n') {
-      int64_t n = (int64_t)(pb - s);
-      memcpy(end(), s, n + 1); // Upto and including '\n'
-      end()[n + 1] = 0;
-      fill(n + 1);
-      return n + 1;
+  bool no_reader = true;
+  for (auto &reader : this->readers) {
+    if (reader.allocated()) {
+      if (reader.is_read_avail_more_than(size)) {
+        return true;
+      }
+      no_reader = false;
     }
-    pc++;
-    pb++;
   }
-  return 0;
+
+  if (no_reader && this->_writer) {
+    return (this->_writer->read_avail() > size);
+  }
+
+  return false;
 }
 
+//
+// IOBufferReader
+//
 int64_t
 IOBufferReader::read(void *ab, int64_t len)
 {
-  char *b           = (char *)ab;
-  int64_t max_bytes = read_avail();
-  int64_t bytes     = len <= max_bytes ? len : max_bytes;
-  int64_t n         = bytes;
+  char *b       = static_cast<char *>(ab);
+  int64_t n     = len;
+  int64_t l     = block_read_avail();
+  int64_t bytes = 0;
 
-  while (n) {
-    int64_t l = block_read_avail();
-    if (n < l)
+  while (n && l) {
+    if (n < l) {
       l = n;
+    }
     ::memcpy(b, start(), l);
     consume(l);
     b += l;
     n -= l;
+    bytes += l;
+    l = block_read_avail();
   }
   return bytes;
 }
@@ -227,14 +195,16 @@ IOBufferReader::memchr(char c, int64_t len, int64_t offset)
       continue;
     }
     int64_t bytes;
-    if (len < 0 || len >= max_bytes)
+    if (len < 0 || len >= max_bytes) {
       bytes = max_bytes;
-    else
+    } else {
       bytes = len;
+    }
     char *s = b->start() + offset;
-    char *p = (char *)::memchr(s, c, bytes);
-    if (p)
-      return (int64_t)(o - start_offset + p - s);
+    char *p = static_cast<char *>(::memchr(s, c, bytes));
+    if (p) {
+      return static_cast<int64_t>(o - start_offset + p - s);
+    }
     o += bytes;
     len -= bytes;
     b      = b->next.get();
@@ -245,9 +215,9 @@ IOBufferReader::memchr(char c, int64_t len, int64_t offset)
 }
 
 char *
-IOBufferReader::memcpy(const void *ap, int64_t len, int64_t offset)
+IOBufferReader::memcpy(void *ap, int64_t len, int64_t offset)
 {
-  char *p          = (char *)ap;
+  char *p          = static_cast<char *>(ap);
   IOBufferBlock *b = block.get();
   offset += start_offset;
 
@@ -260,10 +230,11 @@ IOBufferReader::memcpy(const void *ap, int64_t len, int64_t offset)
       continue;
     }
     int64_t bytes;
-    if (len < 0 || len >= max_bytes)
+    if (len < 0 || len >= max_bytes) {
       bytes = max_bytes;
-    else
+    } else {
       bytes = len;
+    }
     ::memcpy(p, b->start() + offset, bytes);
     p += bytes;
     len -= bytes;
@@ -273,3 +244,93 @@ IOBufferReader::memcpy(const void *ap, int64_t len, int64_t offset)
 
   return p;
 }
+
+//
+// IOBufferChain
+//
+int64_t
+IOBufferChain::write(IOBufferBlock *blocks, int64_t length, int64_t offset)
+{
+  int64_t n = length;
+
+  while (blocks && n > 0) {
+    int64_t block_bytes = blocks->read_avail();
+    if (block_bytes <= offset) { // skip the entire block
+      offset -= block_bytes;
+    } else {
+      int64_t bytes     = std::min(n, block_bytes - offset);
+      IOBufferBlock *bb = blocks->clone();
+      if (offset) {
+        bb->consume(offset);
+        block_bytes -= offset; // bytes really available to use.
+        offset = 0;
+      }
+      if (block_bytes > n) {
+        bb->_end -= (block_bytes - n);
+      }
+      // Attach the cloned block since its data will be kept.
+      this->append(bb);
+      n -= bytes;
+    }
+    blocks = blocks->next.get();
+  }
+
+  length -= n; // actual bytes written to chain.
+  _len += length;
+  return length;
+}
+
+int64_t
+IOBufferChain::write(IOBufferData *data, int64_t length, int64_t offset)
+{
+  int64_t zret     = 0;
+  IOBufferBlock *b = new_IOBufferBlock();
+
+  if (length < 0) {
+    length = 0;
+  }
+
+  b->set(data, length, offset);
+  this->append(b);
+
+  zret = b->read_avail();
+  _len += zret;
+  return zret;
+}
+
+void
+IOBufferChain::append(IOBufferBlock *block)
+{
+  if (nullptr == _tail) {
+    _head = block;
+    _tail = block;
+  } else {
+    _tail->next = block;
+    _tail       = block;
+  }
+}
+
+int64_t
+IOBufferChain::consume(int64_t size)
+{
+  int64_t zret = 0;
+  int64_t bytes;
+  size = std::min(size, _len);
+
+  while (_head != nullptr && size > 0 && (bytes = _head->read_avail()) > 0) {
+    if (size >= bytes) {
+      _head = _head->next;
+      zret += bytes;
+      size -= bytes;
+    } else {
+      _head->consume(size);
+      zret += size;
+      size = 0;
+    }
+  }
+  _len -= zret;
+  if (_head == nullptr || _len == 0) {
+    _head = nullptr, _tail = nullptr, _len = 0;
+  }
+  return zret;
+}
