@@ -23,11 +23,17 @@
 
 #pragma once
 
-#include "ts/ink_platform.h"
-#include "ts/List.h"
+#include <string_view>
+#include <string>
+
+#include "tscore/ink_platform.h"
+#include "tscore/List.h"
+#include "tscore/TsBuffer.h"
 #include "LogFieldAliasMap.h"
 #include "Milestones.h"
 
+enum LogEscapeType { LOG_ESCAPE_NONE, LOG_ESCAPE_JSON };
+
 class LogAccess;
 
 struct LogSlice {
@@ -46,7 +52,7 @@ struct LogSlice {
   // Initialize LogSlice by slice notation,
   // the str looks like: "xxx[0:30]".
   //
-  LogSlice(char *str);
+  explicit LogSlice(char *str);
 
   //
   // Convert slice notation to target string's offset,
@@ -75,7 +81,7 @@ public:
   typedef int (LogAccess::*MarshalFunc)(char *buf);
   typedef int (*UnmarshalFunc)(char **buf, char *dest, int len);
   typedef int (*UnmarshalFuncWithSlice)(char **buf, char *dest, int len, LogSlice *slice);
-  typedef int (*UnmarshalFuncWithMap)(char **buf, char *dest, int len, Ptr<LogFieldAliasMap> map);
+  typedef int (*UnmarshalFuncWithMap)(char **buf, char *dest, int len, const Ptr<LogFieldAliasMap> &map);
   typedef void (LogAccess::*SetFunc)(char *buf, int len);
 
   enum Type {
@@ -116,19 +122,20 @@ public:
     N_AGGREGATES,
   };
 
-  LogField(const char *name, const char *symbol, Type type, MarshalFunc marshal, UnmarshalFunc unmarshal, SetFunc _setFunc = NULL);
+  LogField(const char *name, const char *symbol, Type type, MarshalFunc marshal, UnmarshalFunc unmarshal,
+           SetFunc _setFunc = nullptr);
 
   LogField(const char *name, const char *symbol, Type type, MarshalFunc marshal, UnmarshalFuncWithMap unmarshal,
-           const Ptr<LogFieldAliasMap> &map, SetFunc _setFunc = NULL);
+           const Ptr<LogFieldAliasMap> &map, SetFunc _setFunc = nullptr);
 
-  LogField(const char *field, Container container, SetFunc _setFunc = NULL);
+  LogField(const char *field, Container container, SetFunc _setFunc = nullptr);
   LogField(const LogField &rhs);
   ~LogField();
 
   unsigned marshal_len(LogAccess *lad);
   unsigned marshal(LogAccess *lad, char *buf);
   unsigned marshal_agg(char *buf);
-  unsigned unmarshal(char **buf, char *dest, int len);
+  unsigned unmarshal(char **buf, char *dest, int len, LogEscapeType escape_type = LOG_ESCAPE_NONE);
   void display(FILE *fd = stdout);
   bool operator==(LogField &rhs);
   void updateField(LogAccess *lad, char *val, int len);
@@ -169,13 +176,15 @@ public:
     return m_time_field;
   }
 
+  void set_http_header_field(LogAccess *lad, LogField::Container container, char *field, char *buf, int len);
   void set_aggregate_op(Aggregate agg_op);
   void update_aggregate(int64_t val);
 
-  static void init_milestone_container(void);
+  static void init_milestone_container();
   static Container valid_container_name(char *name);
   static Aggregate valid_aggregate_name(char *name);
-  static bool fieldlist_contains_aggregates(char *fieldlist);
+  static bool fieldlist_contains_aggregates(const char *fieldlist);
+  static bool isContainerUpdateFieldSupported(Container container);
 
 private:
   char *m_name;
@@ -200,13 +209,12 @@ public:
   LINK(LogField, link);
   LogSlice m_slice;
 
-private:
-  // luis, check where this is used and what it does
-  //    void init (char *name, char *symbol, Type type);
-
+  // noncopyable
   // -- member functions that are not allowed --
+  LogField &operator=(const LogField &rhs) = delete;
+
+private:
   LogField();
-  LogField &operator=(const LogField &rhs);
 };
 
 /*-------------------------------------------------------------------------
@@ -242,13 +250,27 @@ public:
   unsigned count();
   void display(FILE *fd = stdout);
 
-private:
-  unsigned m_marshal_len;
-  Queue<LogField> m_field_list;
+  // Add a bad symbol seen in the log format to the list of bad symbols.
+  //
+  void addBadSymbol(std::string_view badSymbol);
 
+  // Return blank-separated list of added bad symbols.
+  //
+  std::string_view
+  badSymbols() const
+  {
+    return _badSymbols;
+  }
+
+  // noncopyable
   // -- member functions that are not allowed --
-  LogFieldList(const LogFieldList &rhs);
-  LogFieldList &operator=(const LogFieldList &rhs);
+  LogFieldList(const LogFieldList &rhs) = delete;
+  LogFieldList &operator=(const LogFieldList &rhs) = delete;
+
+private:
+  unsigned m_marshal_len = 0;
+  Queue<LogField> m_field_list;
+  std::string _badSymbols;
 };
 
 /** Base IP address data.
