@@ -154,4 +154,4 @@ tr5.StillRunningAfter = ts
 # Over riding the built in ERROR check since we expect tr3 to fail
 ts.Disk.diags_log.Content = Testers.ExcludesExpression("verification failed", "Make sure the signatures didn't fail")
 ts.Disk.diags_log.Content += Testers.ContainsExpression(
-    "WARNING: SNI \(bad_bar.com\) not in certificate", "Make sure bad_bar name checked failed.")
+    r"WARNING: SNI \(bad_bar.com\) not in certificate", "Make sure bad_bar name checked failed.")
